@@ -1,7 +1,7 @@
 # ABSTRACT: Keeps track of progress status
 
 package Dancer2::Plugin::ProgressStatus;
-$Dancer2::Plugin::ProgressStatus::VERSION = '0.015';
+$Dancer2::Plugin::ProgressStatus::VERSION = '0.016';
 use strict;
 use warnings;
 
@@ -13,6 +13,7 @@ use JSON qw//;
 
 use Dancer2::Plugin;
 use Dancer2::Plugin::ProgressStatus::Object;
+use Dancer2::Core::Response;
 
 sub _progress_status_file {
     my ( $dsl, $name ) = @_;
@@ -39,9 +40,12 @@ on_plugin_import {
         code    => sub {
             my $context = shift;
             my $data = _get_progress_status_data($dsl, $context->request->params->{'name'});
-            $context->response->content_type('application/json');
 
-            return JSON->new->encode($data);
+            return Dancer2::Core::Response->new(
+                status       => 200,
+                content      => JSON->new->encode($data),
+                content_type => 'application/json',
+            );
         },
     );
 };
@@ -154,7 +158,7 @@ Dancer2::Plugin::ProgressStatus - Keeps track of progress status
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
